#!/usr/bin/env python

''' wmgmail settings

Setup config file for wmgmail.

Copyright (C) 2004 Pasi Savolainen <pasi.savolainen@iki.fi>

Licensed under the GNU General Public License.

'''
import ConfigParser
import os

DEF_CONFIG = { 'username': 'nobody',
               'password': '',
               'check_interval': 5, # minutes
               'browser_command': 'mozilla-firefox %s',
               'pop_qmp': 0, # quick mail preview
               'pop_qmp_timeouts': 0,
               'qmp_timeout': 15, # sec, 0 to disable
               'exec_on_newmail': 0,
               'exec_command': 'xmessage -center -timeout 30 "New Mail in Gmail"',
               'use_geometry': 0,
               'geometry': "+64-64",  # Standard XWindowSystem geometry
               }

DEF_RCNAME = '~/.wmgmailrc';

def getwmgmailsettings(fname):
    config = ConfigParser.ConfigParser(DEF_CONFIG)
    config.read(fname)
    ret = DEF_CONFIG
    ret.update(config.defaults())
    # ugh, these are probably somewhere down there, but don't care enough to dig.
    for key in ret:
        if ret[key] == 'True':
            ret[key] = True
        if ret[key] == 'False':
            ret[key] = False
    return ret

def setwmgmailsettings(fname, settings):
    config = ConfigParser.ConfigParser(settings)
    config.write(open(fname,'w'));

def get_settingsfname():
    """ Get filename of local user settings file
    """
    fname = DEF_RCNAME
    if os.environ.has_key('WMGMAIL_RC'):
        fname = os.environ['WMGMAIL_RC']
    return os.path.expanduser(fname)

def set_settingsfname(fname):
    # we don't want to put in local :)
    global DEF_RCNAME
    DEF_RCNAME = fname;


def get_data_dir():
    """ Get directory that contains our data. most often /usr/share/wmgmail
    """
    if os.environ.has_key('WMGMAIL_DATA'):
        return os.environ['WMGMAIL_DATA']
    
    return os.path.join('/usr','share','wmgmail');

def get_glade_fname():
    return get_data_fname('wmgmail.glade', 'WMGMAIL_GLADE')


def get_data_fname(fname, over_env = None):
    """ Return data fname with possible ENV override.
    """
    if os.environ.has_key(over_env):
        return os.environ(over_env)
    
    return os.path.join(get_data_dir(), fname);

def get_param(param):
    return getwmgmailsettings(get_settingsfname())[param]

def get_geometry():
    if get_param('use_geometry'):
        return get_param('geometry')
    return ""
